

import 'package:flutter/services.dart';
import 'package:flutter_nayax_ble_sdk_mock/vpos_device.dart';
import 'package:rxdart/rxdart.dart';

abstract class NayaxBleSDK{

  static NayaxBleSDK? _instance;

  factory NayaxBleSDK(){
    var instance = _instance;
    if (instance == null){
      instance = NayaxBleSDKImpl();
      _instance = instance;
    }

    return instance;
  }

  /// must call this before using nayax sdk
  Future init();

  Future dispose();

  startScan();

  stopScan();

  Stream<List<VposTouchDevice>> scanResult();

  Future<String> getDex({VposTouchDevice? device, String? identifier});


}

class NayaxBleSDKImpl implements NayaxBleSDK{


  final scanResultSubject = BehaviorSubject<List<VposTouchDevice>>();
  @override
  Future dispose() async{
  }

  @override
  Future<String> getDex({device, String? identifier}) async {
    await Future.delayed(const Duration(seconds: 4));
    return await rootBundle.loadString("assets/dex/temp_dex.txt");
  }

  @override
  Future init() async {

  }


  @override
  startScan() {
    final scanResult = <VposTouchDevice>[];
    scanResult.add(VposTouchDevice(12345, "123456789", 9999,secondaryAdvertisement: SecondaryAdvertisement("987654","Nayax_BLE1")));
    scanResult.add(VposTouchDevice(12346, "123466789", 9999,secondaryAdvertisement: SecondaryAdvertisement("987655","Nayax_BLE2")));
    scanResult.add(VposTouchDevice(12347, "123476789", 9999,secondaryAdvertisement: SecondaryAdvertisement("987656","Nayax_BLE3")));

    scanResultSubject.add(scanResult);
  }

  @override
  stopScan() {
    scanResultSubject.add([]);
  }

  @override
  Stream<List<VposTouchDevice>> scanResult() {
    return scanResultSubject;
  }

}